/*
 * Stub definitions of the GSSAPI library list, for Unix pterm and
 * any other application that needs the symbols defined but has no
 * use for them.
 */

#include "putty.h"

const int ngsslibs = 0;
const char *const gsslibnames[1] = { "dummy" };
const struct keyvalwhere gsslibkeywords[1] = { { "dummy", 0, -1, -1 } };
